@@ -3,11 +3,12 @@ from numpy import dtype
 from sqlalchemy.types import Boolean, DateTime, Float, Integer, String
 import os
 import logging
+import tempfile
 from df_to_azure.adf import create_blob_service_client
 import df_to_azure.adf as adf
 from df_to_azure.parse_settings import TableParameters
 from df_to_azure.db import SqlUpsert, auth_azure, test_uniqueness_columns
-from df_to_azure.functions import create_dir, wait_until_pipeline_is_done
+from df_to_azure.functions import wait_until_pipeline_is_done
 
 
 def table_list(df_dict: dict, schema: str, method: str, id_field: str, cwd: str) -> list:
@@ -126,20 +127,20 @@ def upload_dataset(table):
 
 
 def push_to_azure(table):
-    con = auth_azure()
     table.df = convert_timedelta_to_seconds(table.df)
     max_str = get_max_str_len(table.df)
     col_types = column_types(table.df)
     col_types.update(max_str)
 
-    table.df.head(n=0).to_sql(
-        name=table.name,
-        con=con,
-        if_exists="replace",
-        index=False,
-        schema=table.schema,
-        dtype=col_types,
-    )
+    with auth_azure() as con:
+        table.df.head(n=0).to_sql(
+            name=table.name,
+            con=con,
+            if_exists="replace",
+            index=False,
+            schema=table.schema,
+            dtype=col_types,
+        )
 
     logging.info(f"created {table.df.shape[1]} columns in {table.schema}.{table.name}.")
 
@@ -150,20 +151,16 @@ def upload_to_blob(table):
         container=os.environ.get("ls_blob_container_name"),
         blob=f"{table.name}/{table.name}",
     )
-    tmp_path = os.path.join(os.path.expanduser("~"), "tmp", "df_to_azure")
-    full_path_to_file = os.path.join(tmp_path, table.name + ".csv")
-    create_dir(tmp_path)
+    with tempfile.TemporaryDirectory(suffix="_df_to_azure") as temp_dir:
+        full_path_to_file = os.path.join(temp_dir, table.name + ".csv")
+        table.df.to_csv(
+            full_path_to_file, index=False, sep="^", quotechar='"', line_terminator="\n"
+        )  # export file to staging
 
-    table.df.to_csv(
-        full_path_to_file, index=False, sep="^", quotechar='"', line_terminator="\n"
-    )  # export file to staging
-
-    logging.debug(f"start uploading blob {table.name}...")
-    with open(full_path_to_file, "rb") as data:
-        blob_client.upload_blob(data, overwrite=True)
-    logging.debug(f"finished uploading blob {table.name}!")
-
-    os.remove(full_path_to_file)
+        logging.debug(f"start uploading blob {table.name}...")
+        with open(full_path_to_file, "rb") as data:
+            blob_client.upload_blob(data, overwrite=True)
+        logging.debug(f"finished uploading blob {table.name}!")
 
 
 def create_schema(table):
@@ -187,62 +184,6 @@ def execute_stmt(stmt):
         t.commit()
 
 
-def delete_current_records(table):
-    """
-    :param df: the dataframe containing new records
-    :param tablename: the name of the table
-    :param schema: schema in the database
-    :param id_field: field to check if the values are already in the database
-    :return: executes a delete statement in Azure SQL for the new records.
-    """
-
-    del_list = get_overlapping_records(table)
-    stmt = create_sql_delete_stmt(del_list, table)
-
-    if len(del_list):
-        execute_stmt(stmt)
-    else:
-        logging.info("skip deleting. no records in delete statement")
-
-
-def get_overlapping_records(table):
-    """
-    :param df: the dataframe containing new records
-    :param tablename: the name of the table
-    :param schema: schema in the database
-    :param id_field: field to check if the values are already in the database
-    :return:  a list of records that are overlapping
-    """
-    con = auth_azure()
-
-    current_db = pd.read_sql_table(table_name=table.name, con=con, schema=table.schema)
-    overlapping_records = current_db[current_db[table.id_field].isin(table.df[table.id_field])]
-    del_list = overlapping_records.astype(str)[table.id_field].to_list()
-
-    new_records = table.df[~table.df[table.id_field].isin(current_db[table.id_field])]
-    logging.info(f"{len(overlapping_records)} updated records and {len(new_records)} new records")
-
-    return del_list
-
-
-def create_sql_delete_stmt(del_list, table):
-    """
-    :param del_list: list of records that need to be formatted in SQL delete statement.
-    :param tablename: the name of the table
-    :param schema: schema in the database
-    :param id_field: field to check if the values are already in the database
-    :return: SQL statement for deleting the specific records
-    """
-
-    del_list = ["'" + x + "'" for x in del_list]
-
-    sql_list = ", ".join(del_list)
-    sql_stmt = f"DELETE FROM {table.schema}.{table.name} WHERE {table.id_field} IN ({sql_list})"
-    logging.info(f"{len(del_list)} run_id's in delete statement")
-
-    return sql_stmt
-
-
 def convert_timedelta_to_seconds(df: pd.DataFrame) -> pd.DataFrame:
     """
     We convert timedelta columns to seconds since this will error in SQL DB.
